
gradients = (  # gradients which can be chosen when creating a video object later
    ' `-~+#@',  # good for high light/contrast environments
    ' \'³•†îuÍµðEÆ',  # low light low contrast environments
    ' ░▒▓█',
)
